The role of the First–tier Tribunal (Estate Agents) was to hear and decide appeals under the Estate Agents Act 1979. The Tribunal heard appeals against decisions made by the Office of Fair Trading relating to an order prohibiting a person from acting as an estate agent where for example:

- a person has been convicted of an offence involving fraud or other dishonesty
- an order warning a person where for example that person has not met their duties under the 1979 Act
- a decision refusing to revoke or vary a prohibition order or warning order made under the 1979 Act

In 2009, the function of the Secretary of State to decide appeals from decisions made by the Office of Fair Trading under the Estate Agents Act 1979 was transferred to the First-tier Tribunal (Estate Agents), part of the General Regulatory Chamber which hears appeals against decisions made by government regulatory bodies. The Office of Fair Trading was abolished in 2014.
